 SUBROUTINE write_var_list

!------------------------------------------------------------------------------!
! Current revisions:
! -----------------
! 
!
! Former revisions:
! -----------------
! $Id: write_var_list.f90 928 2012-06-06 19:54:18Z raasch $
!
! 927 2012-06-06 19:15:04Z raasch
! +masking_method
!
! 849 2012-03-15 10:35:09Z raasch
! first_call_advec_particles renamed first_call_lpm
!
! 824 2012-02-17 09:09:57Z raasch
! +curvature_solution_effects
!
! 622 2010-12-10 08:08:13Z raasch
! +collective_wait
!
! 600 2010-11-24 16:10:51Z raasch
! +call_psolver_at_all_substeps, cfl_factor, cycle_mg, mg_cycles,
! mg_switch_to_pe0_level, ngsrb, nsor, omega_sor, psolver,
! rayleigh_damping_factor, rayleigh_damping_height, residual_limit
!
! 589 2010-10-27 14:21:29Z heinze
! bugfix: character string of subs_vertical_gradient and 
! subs_vertical_gradient_level shortened to 30 characters
!
! 587 2010-10-27 08:36:51Z helmke
! +time_domask
!
! 580 2010-10-05 13:59:11Z heinze
! Renaming of ws_vertical_gradient to subs_vertical_gradient,
! ws_vertical_gradient_level to subs_vertical_gradient_level and
! ws_vertical_gradient_level_ind to subs_vertical_gradient_level_i
!
! 411 2009-12-11 14:15:58Z heinze
! +large_scale_subsidence, ws_vertical_gradient, ws_vertical_gradient_level,
! ws_vertical_gradient_level_ind
!
! 345 2009-07-01 14:37:56Z heinze
! +output_for_t0 
! bugfix: -dt_fixed, because otherwise, restart runs cannot change from a
! fixed to a free timestep.
! +canyon_height, canyon_width_x, canyon_width_y, canyon_wall_left, 
! canyon_wall_south, conserve_volume_flow_mode, coupling_start_time,
! dp_external, dp_level_b, dp_smooth, dpdxy, run_coupled,
! time_since_reference_point, topography_grid_convention, u_bulk, v_bulk
!
! 153 2008-03-19 09:41:30Z steinfeld
! +cthf, leaf_surface_concentration, scalar_exchange_coefficient
! +numprocs, hor_index_bounds, inflow_damping_height, inflow_damping_width,
! mean_inflow_profiles, recycling_width, turbulent_inflow,
! -cross_ts_*, npex, npey
! hom_sum, volume_flow_area, volume_flow_initial moved from write_3d_binary
! to here
!
! 138 2007-11-28 10:03:58Z letzel
! +canopy_mode, drag_coefficient, lad, lad_surface, lad_vertical_gradient, 
! lad_vertical_gradient_level, lad_vertical_gradient_level_ind, pch_index,
! plant_canopy, time_sort_particles
!
! 102 2007-07-27 09:09:17Z raasch
! +top_momentumflux_u|v, time_coupling
!
! 95 2007-06-02 16:48:38Z raasch
! +bc_sa_t, ocean, sa_init, sa_surface, sa_vertical_gradient,
! sa_vertical_gradient_level, bottom/top_salinity_flux
!
! 87 2007-05-22 15:46:47Z raasch
! +max_pr_user (version 3.1)
!
! 75 2007-03-22 09:54:05Z raasch
! +loop_optimization, pt_refrence, moisture renamed humidity
!
! 20 2007-02-26 00:12:32Z raasch
! +top_heatflux, use_top_fluxes
!
! RCS Log replace by Id keyword, revision history cleaned up
!
! Revision 1.34  2006/08/22 14:30:52  raasch
! +dz_max
!
! Revision 1.1  1998/03/18 20:20:38  raasch
! Initial revision
!
!
! Description:
! ------------
! Writing values of control variables to restart-file (binary format).
! These informations are only written to the file opened by PE0.
!------------------------------------------------------------------------------!

    USE arrays_3d
    USE averaging
    USE cloud_parameters
    USE control_parameters
    USE grid_variables
    USE indices
    USE model_1d
    USE netcdf_control
    USE particle_attributes
    USE pegrid
    USE profil_parameter
    USE statistics

    IMPLICIT NONE

    CHARACTER (LEN=10) ::  binary_version


    binary_version = '3.5'

    WRITE ( 14 )  binary_version

    WRITE ( 14 )  'numprocs                      '
    WRITE ( 14 )  numprocs
    WRITE ( 14 )  'hor_index_bounds              '
    WRITE ( 14 )  hor_index_bounds
    WRITE ( 14 )  'nz                            '
    WRITE ( 14 )  nz
    WRITE ( 14 )  'max_pr_user                   '
    WRITE ( 14 )  max_pr_user
    WRITE ( 14 )  'statistic_regions             '
    WRITE ( 14 )  statistic_regions

!
!-- Caution: After changes in the following parameter-list, the
!-- -------  version number stored in the variable binary_version has to be
!--          increased. The same changes must also be done in the parameter-
!--          list in read_var_list.

    WRITE ( 14 )  'adjust_mixing_length          '
    WRITE ( 14 )  adjust_mixing_length
    WRITE ( 14 )  'advected_distance_x           '
    WRITE ( 14 )  advected_distance_x
    WRITE ( 14 )  'advected_distance_y           '
    WRITE ( 14 )  advected_distance_y
    WRITE ( 14 )  'alpha_surface                 '
    WRITE ( 14 )  alpha_surface
    WRITE ( 14 )  'average_count_pr              '
    WRITE ( 14 )  average_count_pr
    WRITE ( 14 )  'average_count_sp              '
    WRITE ( 14 )  average_count_sp
    WRITE ( 14 )  'average_count_3d              '
    WRITE ( 14 )  average_count_3d
    WRITE ( 14 )  'bc_e_b                        '
    WRITE ( 14 )  bc_e_b
    WRITE ( 14 )  'bc_lr                         '
    WRITE ( 14 )  bc_lr
    WRITE ( 14 )  'bc_ns                         '
    WRITE ( 14 )  bc_ns
    WRITE ( 14 )  'bc_p_b                        '
    WRITE ( 14 )  bc_p_b
    WRITE ( 14 )  'bc_p_t                        '
    WRITE ( 14 )  bc_p_t
    WRITE ( 14 )  'bc_pt_b                       '
    WRITE ( 14 )  bc_pt_b
    WRITE ( 14 )  'bc_pt_t                       '
    WRITE ( 14 )  bc_pt_t
    WRITE ( 14 )  'bc_pt_t_val                   '
    WRITE ( 14 )  bc_pt_t_val
    WRITE ( 14 )  'bc_q_b                        '
    WRITE ( 14 )  bc_q_b
    WRITE ( 14 )  'bc_q_t                        '
    WRITE ( 14 )  bc_q_t
    WRITE ( 14 )  'bc_q_t_val                    '
    WRITE ( 14 )  bc_q_t_val
    WRITE ( 14 )  'bc_s_b                        '
    WRITE ( 14 )  bc_s_b
    WRITE ( 14 )  'bc_s_t                        '
    WRITE ( 14 )  bc_s_t
    WRITE ( 14 )  'bc_sa_t                       '
    WRITE ( 14 )  bc_sa_t
    WRITE ( 14 )  'bc_uv_b                       '
    WRITE ( 14 )  bc_uv_b
    WRITE ( 14 )  'bc_uv_t                       '
    WRITE ( 14 )  bc_uv_t
    WRITE ( 14 )  'bottom_salinityflux           '
    WRITE ( 14 )  bottom_salinityflux
    WRITE ( 14 )  'building_height               '
    WRITE ( 14 )  building_height
    WRITE ( 14 )  'building_length_x             '
    WRITE ( 14 )  building_length_x
    WRITE ( 14 )  'building_length_y             '
    WRITE ( 14 )  building_length_y
    WRITE ( 14 )  'building_wall_left            '
    WRITE ( 14 )  building_wall_left
    WRITE ( 14 )  'building_wall_south           '
    WRITE ( 14 )  building_wall_south
    WRITE ( 14 )  'call_psolver_at_all_substeps  '
    WRITE ( 14 )  call_psolver_at_all_substeps
    WRITE ( 14 )  'canopy_mode                   '
    WRITE ( 14 )  canopy_mode
    WRITE ( 14 )  'canyon_height                 '
    WRITE ( 14 )  canyon_height
    WRITE ( 14 )  'canyon_width_x                '
    WRITE ( 14 )  canyon_width_x
    WRITE ( 14 )  'canyon_width_y                '
    WRITE ( 14 )  canyon_width_y
    WRITE ( 14 )  'canyon_wall_left              '
    WRITE ( 14 )  canyon_wall_left
    WRITE ( 14 )  'canyon_wall_south             '
    WRITE ( 14 )  canyon_wall_south
    WRITE ( 14 )  'cfl_factor                    '
    WRITE ( 14 )  cfl_factor
    WRITE ( 14 )  'cloud_droplets                '
    WRITE ( 14 )  cloud_droplets
    WRITE ( 14 )  'cloud_physics                 '
    WRITE ( 14 )  cloud_physics
    WRITE ( 14 )  'collective_wait               '
    WRITE ( 14 )  collective_wait
    WRITE ( 14 )  'conserve_volume_flow          '
    WRITE ( 14 )  conserve_volume_flow
    WRITE ( 14 )  'conserve_volume_flow_mode     '
    WRITE ( 14 )  conserve_volume_flow_mode
    WRITE ( 14 )  'coupling_start_time           '
    WRITE ( 14 )  coupling_start_time
    WRITE ( 14 )  'current_timestep_number       '
    WRITE ( 14 )  current_timestep_number
    WRITE ( 14 )  'curvature_solution_effects    '
    WRITE ( 14 )  curvature_solution_effects
    WRITE ( 14 )  'cthf                          '
    WRITE ( 14 )  cthf
    WRITE ( 14 )  'cut_spline_overshoot          '
    WRITE ( 14 )  cut_spline_overshoot
    WRITE ( 14 )  'cycle_mg                      '
    WRITE ( 14 )  cycle_mg
    WRITE ( 14 )  'damp_level_1d                 '
    WRITE ( 14 )  damp_level_1d
    WRITE ( 14 )  'dissipation_1d                '
    WRITE ( 14 )  dissipation_1d
    WRITE ( 14 )  'dp_external                   '
    WRITE ( 14 )  dp_external
    WRITE ( 14 )  'dp_level_b                    '
    WRITE ( 14 )  dp_level_b
    WRITE ( 14 )  'dp_smooth                     '
    WRITE ( 14 )  dp_smooth
    WRITE ( 14 )  'dpdxy                         '
    WRITE ( 14 )  dpdxy
    WRITE ( 14 )  'drag_coefficient              '
    WRITE ( 14 )  drag_coefficient
    WRITE ( 14 )  'dt_pr_1d                      '
    WRITE ( 14 )  dt_pr_1d
    WRITE ( 14 )  'dt_run_control_1d             '
    WRITE ( 14 )  dt_run_control_1d
    WRITE ( 14 )  'dt_3d                         '
    WRITE ( 14 )  dt_3d
    WRITE ( 14 )  'dvrp_filecount                '
    WRITE ( 14 )  dvrp_filecount
    WRITE ( 14 )  'dx                            '
    WRITE ( 14 )  dx
    WRITE ( 14 )  'dy                            '
    WRITE ( 14 )  dy
    WRITE ( 14 )  'dz                            '
    WRITE ( 14 )  dz
    WRITE ( 14 )  'dz_max                        '
    WRITE ( 14 )  dz_max
    WRITE ( 14 )  'dz_stretch_factor             '
    WRITE ( 14 )  dz_stretch_factor
    WRITE ( 14 )  'dz_stretch_level              '
    WRITE ( 14 )  dz_stretch_level
    WRITE ( 14 )  'e_min                         '
    WRITE ( 14 )  e_min
    WRITE ( 14 )  'end_time_1d                   '
    WRITE ( 14 )  end_time_1d
    WRITE ( 14 )  'fft_method                    '
    WRITE ( 14 )  fft_method
    WRITE ( 14 )  'first_call_lpm                '
    WRITE ( 14 )  first_call_lpm
    WRITE ( 14 )  'galilei_transformation        '
    WRITE ( 14 )  galilei_transformation
    WRITE ( 14 )  'grid_matching                 '
    WRITE ( 14 )  grid_matching
    WRITE ( 14 )  'hom                           '
    WRITE ( 14 )  hom
    WRITE ( 14 )  'hom_sum                       '
    WRITE ( 14 )  hom_sum
    WRITE ( 14 )  'humidity                      '
    WRITE ( 14 )  humidity
    IF ( ALLOCATED( inflow_damping_factor ) )  THEN
       WRITE ( 14 )  'inflow_damping_factor         '
       WRITE ( 14 )  inflow_damping_factor
    ENDIF
    WRITE ( 14 )  'inflow_damping_height         '
    WRITE ( 14 )  inflow_damping_height
    WRITE ( 14 )  'inflow_damping_width          '
    WRITE ( 14 )  inflow_damping_width
    WRITE ( 14 )  'inflow_disturbance_begin      '
    WRITE ( 14 )  inflow_disturbance_begin
    WRITE ( 14 )  'inflow_disturbance_end        '
    WRITE ( 14 )  inflow_disturbance_end
    WRITE ( 14 )  'km_constant                   '
    WRITE ( 14 )  km_constant
    WRITE ( 14 )  'km_damp_max                   '
    WRITE ( 14 )  km_damp_max
    WRITE ( 14 )  'lad                           '
    WRITE ( 14 )  lad
    WRITE ( 14 )  'lad_surface                   '
    WRITE ( 14 )  lad_surface
    WRITE ( 14 )  'lad_vertical_gradient         '
    WRITE ( 14 )  lad_vertical_gradient
    WRITE ( 14 )  'lad_vertical_gradient_level   '
    WRITE ( 14 )  lad_vertical_gradient_level
    WRITE ( 14 )  'lad_vertical_gradient_level_in'
    WRITE ( 14 )  lad_vertical_gradient_level_ind
    WRITE ( 14 )  'last_dt_change                '
    WRITE ( 14 )  last_dt_change
    WRITE ( 14 )  'large_scale_subsidence        '
    WRITE ( 14 )  large_scale_subsidence
    WRITE ( 14 )  'leaf_surface_concentration    '
    WRITE ( 14 )  leaf_surface_concentration
    WRITE ( 14 )  'long_filter_factor            '
    WRITE ( 14 )  long_filter_factor
    WRITE ( 14 )  'loop_optimization             '
    WRITE ( 14 )  loop_optimization
    WRITE ( 14 )  'masking_method                '
    WRITE ( 14 )  masking_method
    IF ( ALLOCATED( mean_inflow_profiles ) )  THEN
       WRITE ( 14 )  'mean_inflow_profiles          '
       WRITE ( 14 )  mean_inflow_profiles
    ENDIF
    WRITE ( 14 )  'mg_cycles                     '
    WRITE ( 14 )  mg_cycles
    WRITE ( 14 )  'mg_switch_to_pe0_level        '
    WRITE ( 14 )  mg_switch_to_pe0_level
    WRITE ( 14 )  'mixing_length_1d              '
    WRITE ( 14 )  mixing_length_1d
    WRITE ( 14 )  'momentum_advec                '
    WRITE ( 14 )  momentum_advec
    WRITE ( 14 )  'netcdf_precision              '
    WRITE ( 14 )  netcdf_precision
    WRITE ( 14 )  'ngsrb                         '
    WRITE ( 14 )  ngsrb
    WRITE ( 14 )  'nsor                          '
    WRITE ( 14 )  nsor
    WRITE ( 14 )  'nsor_ini                      '
    WRITE ( 14 )  nsor_ini
    WRITE ( 14 )  'nx                            '
    WRITE ( 14 )  nx
    WRITE ( 14 )  'ny                            '
    WRITE ( 14 )  ny
    WRITE ( 14 )  'ocean                         '
    WRITE ( 14 )  ocean
    WRITE ( 14 )  'old_dt                        '
    WRITE ( 14 )  old_dt
    WRITE ( 14 )  'omega                         '
    WRITE ( 14 )  omega
    WRITE ( 14 )  'omega_sor                     '
    WRITE ( 14 )  omega_sor
    WRITE ( 14 )  'outflow_damping_width         '
    WRITE ( 14 )  outflow_damping_width
    WRITE ( 14 )  'output_for_t0                 '
    WRITE ( 14 )  output_for_t0
    WRITE ( 14 )  'overshoot_limit_e             '
    WRITE ( 14 )  overshoot_limit_e
    WRITE ( 14 )  'overshoot_limit_pt            '
    WRITE ( 14 )  overshoot_limit_pt
    WRITE ( 14 )  'overshoot_limit_u             '
    WRITE ( 14 )  overshoot_limit_u
    WRITE ( 14 )  'overshoot_limit_v             '
    WRITE ( 14 )  overshoot_limit_v
    WRITE ( 14 )  'overshoot_limit_w             '
    WRITE ( 14 )  overshoot_limit_w
    WRITE ( 14 )  'passive_scalar                '
    WRITE ( 14 )  passive_scalar
    WRITE ( 14 )  'pch_index                     '
    WRITE ( 14 )  pch_index
    WRITE ( 14 )  'phi                           '
    WRITE ( 14 )  phi
    WRITE ( 14 )  'plant_canopy                  '
    WRITE ( 14 )  plant_canopy
    WRITE ( 14 )  'prandtl_layer                 '
    WRITE ( 14 )  prandtl_layer
    WRITE ( 14 )  'prandtl_number                '
    WRITE ( 14 )  prandtl_number
    WRITE ( 14 )  'precipitation                 '
    WRITE ( 14 )  precipitation
    WRITE ( 14 )  'psolver                       '
    WRITE ( 14 )  psolver
    WRITE ( 14 )  'pt_init                       '
    WRITE ( 14 )  pt_init
    WRITE ( 14 )  'pt_reference                  '
    WRITE ( 14 )  pt_reference
    WRITE ( 14 )  'pt_surface                    '
    WRITE ( 14 )  pt_surface
    WRITE ( 14 )  'pt_surface_initial_change     '
    WRITE ( 14 )  pt_surface_initial_change
    WRITE ( 14 )  'pt_vertical_gradient          '
    WRITE ( 14 )  pt_vertical_gradient
    WRITE ( 14 )  'pt_vertical_gradient_level    '
    WRITE ( 14 )  pt_vertical_gradient_level
    WRITE ( 14 )  'pt_vertical_gradient_level_ind'
    WRITE ( 14 )  pt_vertical_gradient_level_ind
    WRITE ( 14 )  'q_init                        '
    WRITE ( 14 )  q_init
    WRITE ( 14 )  'q_surface                     '
    WRITE ( 14 )  q_surface
    WRITE ( 14 )  'q_surface_initial_change      '
    WRITE ( 14 )  q_surface_initial_change
    WRITE ( 14 )  'q_vertical_gradient           '
    WRITE ( 14 )  q_vertical_gradient
    WRITE ( 14 )  'q_vertical_gradient_level     '
    WRITE ( 14 )  q_vertical_gradient_level
    WRITE ( 14 )  'q_vertical_gradient_level_ind '
    WRITE ( 14 )  q_vertical_gradient_level_ind
    WRITE ( 14 )  'radiation                     '
    WRITE ( 14 )  radiation
    WRITE ( 14 )  'random_generator              '
    WRITE ( 14 )  random_generator
    WRITE ( 14 )  'random_heatflux               '
    WRITE ( 14 )  random_heatflux
    WRITE ( 14 )  'rayleigh_damping_factor       '
    WRITE ( 14 )  rayleigh_damping_factor
    WRITE ( 14 )  'rayleigh_damping_height       '
    WRITE ( 14 )  rayleigh_damping_height
    WRITE ( 14 )  'recycling_width               '
    WRITE ( 14 )  recycling_width
    WRITE ( 14 )  'residual_limit                '
    WRITE ( 14 )  residual_limit
    WRITE ( 14 )  'rif_max                       '
    WRITE ( 14 )  rif_max
    WRITE ( 14 )  'rif_min                       '
    WRITE ( 14 )  rif_min
    WRITE ( 14 )  'roughness_length              '
    WRITE ( 14 )  roughness_length
    WRITE ( 14 )  'runnr                         '
    WRITE ( 14 )  runnr
    WRITE ( 14 )  'run_coupled                   '
    WRITE ( 14 )  run_coupled
    WRITE ( 14 )  'sa_init                       '
    WRITE ( 14 )  sa_init
    WRITE ( 14 )  'sa_surface                    '
    WRITE ( 14 )  sa_surface
    WRITE ( 14 )  'sa_vertical_gradient          '
    WRITE ( 14 )  sa_vertical_gradient
    WRITE ( 14 )  'sa_vertical_gradient_level    '
    WRITE ( 14 )  sa_vertical_gradient_level
    WRITE ( 14 )  'scalar_advec                  '
    WRITE ( 14 )  scalar_advec
    WRITE ( 14 )  'scalar_exchange_coefficient   '
    WRITE ( 14 )  scalar_exchange_coefficient
    WRITE ( 14 )  'simulated_time                '
    WRITE ( 14 )  simulated_time
    WRITE ( 14 )  'surface_heatflux              '
    WRITE ( 14 )  surface_heatflux
    WRITE ( 14 )  'surface_pressure              '
    WRITE ( 14 )  surface_pressure
    WRITE ( 14 )  'surface_scalarflux            '
    WRITE ( 14 )  surface_scalarflux    
    WRITE ( 14 )  'surface_waterflux             '
    WRITE ( 14 )  surface_waterflux    
    WRITE ( 14 )  's_surface                     '
    WRITE ( 14 )  s_surface
    WRITE ( 14 )  's_surface_initial_change      '
    WRITE ( 14 )  s_surface_initial_change
    WRITE ( 14 )  's_vertical_gradient           '
    WRITE ( 14 )  s_vertical_gradient
    WRITE ( 14 )  's_vertical_gradient_level     '
    WRITE ( 14 )  s_vertical_gradient_level
    WRITE ( 14 )  'time_coupling                 '
    WRITE ( 14 )  time_coupling
    WRITE ( 14 )  'time_disturb                  '
    WRITE ( 14 )  time_disturb
    WRITE ( 14 )  'time_domask                   '
    WRITE ( 14 )  time_domask
    WRITE ( 14 )  'time_dopr                     '
    WRITE ( 14 )  time_dopr
    WRITE ( 14 )  'time_dopr_av                  '
    WRITE ( 14 )  time_dopr_av
    WRITE ( 14 )  'time_dopr_listing             '
    WRITE ( 14 )  time_dopr_listing
    WRITE ( 14 )  'time_dopts                    '
    WRITE ( 14 )  time_dopts
    WRITE ( 14 )  'time_dosp                     '
    WRITE ( 14 )  time_dosp
    WRITE ( 14 )  'time_dots                     '
    WRITE ( 14 )  time_dots
    WRITE ( 14 )  'time_do2d_xy                  '
    WRITE ( 14 )  time_do2d_xy
    WRITE ( 14 )  'time_do2d_xz                  '
    WRITE ( 14 )  time_do2d_xz
    WRITE ( 14 )  'time_do2d_yz                  '
    WRITE ( 14 )  time_do2d_yz
    WRITE ( 14 )  'time_do3d                     '
    WRITE ( 14 )  time_do3d
    WRITE ( 14 )  'time_do_av                    '
    WRITE ( 14 )  time_do_av
    WRITE ( 14 )  'time_do_sla                   '
    WRITE ( 14 )  time_do_sla
    WRITE ( 14 )  'time_dvrp                     '
    WRITE ( 14 )  time_dvrp
    WRITE ( 14 )  'time_restart                  '
    WRITE ( 14 )  time_restart
    WRITE ( 14 )  'time_run_control              '
    WRITE ( 14 )  time_run_control
    WRITE ( 14 )  'time_since_reference_point    '
    WRITE ( 14 )  time_since_reference_point
    WRITE ( 14 )  'time_sort_particles           '
    WRITE ( 14 )  time_sort_particles
    WRITE ( 14 )  'timestep_scheme               '
    WRITE ( 14 )  timestep_scheme
    WRITE ( 14 )  'topography                    '
    WRITE ( 14 )  topography
    WRITE ( 14 )  'topography_grid_convention    '
    WRITE ( 14 )  topography_grid_convention
    WRITE ( 14 )  'top_heatflux                  '
    WRITE ( 14 )  top_heatflux
    WRITE ( 14 )  'top_momentumflux_u            '
    WRITE ( 14 )  top_momentumflux_u
    WRITE ( 14 )  'top_momentumflux_v            '
    WRITE ( 14 )  top_momentumflux_v
    WRITE ( 14 )  'top_salinityflux              '
    WRITE ( 14 )  top_salinityflux
    WRITE ( 14 )  'tsc                           '
    WRITE ( 14 )  tsc
    WRITE ( 14 )  'turbulent_inflow              '
    WRITE ( 14 )  turbulent_inflow
    WRITE ( 14 )  'u_bulk                        '
    WRITE ( 14 )  u_bulk
    WRITE ( 14 )  'u_init                        '
    WRITE ( 14 )  u_init
    WRITE ( 14 )  'u_max                         '
    WRITE ( 14 )  u_max
    WRITE ( 14 )  'u_max_ijk                     '
    WRITE ( 14 )  u_max_ijk
    WRITE ( 14 )  'ug                            '
    WRITE ( 14 )  ug
    WRITE ( 14 )  'ug_surface                    '
    WRITE ( 14 )  ug_surface
    WRITE ( 14 )  'ug_vertical_gradient          '
    WRITE ( 14 )  ug_vertical_gradient
    WRITE ( 14 )  'ug_vertical_gradient_level    '
    WRITE ( 14 )  ug_vertical_gradient_level
    WRITE ( 14 )  'ug_vertical_gradient_level_ind'
    WRITE ( 14 )  ug_vertical_gradient_level_ind
    WRITE ( 14 )  'ups_limit_e                   '
    WRITE ( 14 )  ups_limit_e
    WRITE ( 14 )  'ups_limit_pt                  '
    WRITE ( 14 )  ups_limit_pt
    WRITE ( 14 )  'ups_limit_u                   '
    WRITE ( 14 )  ups_limit_u
    WRITE ( 14 )  'ups_limit_v                   '
    WRITE ( 14 )  ups_limit_v
    WRITE ( 14 )  'ups_limit_w                   '
    WRITE ( 14 )  ups_limit_w
    WRITE ( 14 )  'use_surface_fluxes            '
    WRITE ( 14 )  use_surface_fluxes
    WRITE ( 14 )  'use_top_fluxes                '
    WRITE ( 14 )  use_top_fluxes
    WRITE ( 14 )  'use_ug_for_galilei_tr         '
    WRITE ( 14 )  use_ug_for_galilei_tr
    WRITE ( 14 )  'use_upstream_for_tke          '
    WRITE ( 14 )  use_upstream_for_tke
    WRITE ( 14 )  'v_bulk                        '
    WRITE ( 14 )  v_bulk
    WRITE ( 14 )  'v_init                        '
    WRITE ( 14 )  v_init
    WRITE ( 14 )  'v_max                         '
    WRITE ( 14 )  v_max
    WRITE ( 14 )  'v_max_ijk                     '
    WRITE ( 14 )  v_max_ijk
    WRITE ( 14 )  'vg                            '
    WRITE ( 14 )  vg
    WRITE ( 14 )  'vg_surface                    '
    WRITE ( 14 )  vg_surface
    WRITE ( 14 )  'vg_vertical_gradient          '
    WRITE ( 14 )  vg_vertical_gradient
    WRITE ( 14 )  'vg_vertical_gradient_level    '
    WRITE ( 14 )  vg_vertical_gradient_level
    WRITE ( 14 )  'vg_vertical_gradient_level_ind'
    WRITE ( 14 )  vg_vertical_gradient_level_ind
    WRITE ( 14 )  'volume_flow_area              '
    WRITE ( 14 )  volume_flow_area
    WRITE ( 14 )  'volume_flow_initial           '
    WRITE ( 14 )  volume_flow_initial
    WRITE ( 14 )  'wall_adjustment               '
    WRITE ( 14 )  wall_adjustment
    WRITE ( 14 )  'subs_vertical_gradient        '
    WRITE ( 14 )  subs_vertical_gradient
    WRITE ( 14 )  'subs_vertical_gradient_level  '
    WRITE ( 14 )  subs_vertical_gradient_level
    WRITE ( 14 )  'subs_vertical_gradient_level_i'
    WRITE ( 14 )  subs_vertical_gradient_level_i
    WRITE ( 14 )  'w_max                         '
    WRITE ( 14 )  w_max
    WRITE ( 14 )  'w_max_ijk                     '
    WRITE ( 14 )  w_max_ijk

!
!-- Set the end-of-file mark
    WRITE ( 14 )  '*** end ***                   '


 END SUBROUTINE write_var_list
